Package: planttfhunter
Title: Identification and classification of plant transcription factors
Version: 1.12.0
Date: 2022-03-10
Authors@R: 
    c(
    person(given = "Fabrício",
           family = "Almeida-Silva",
           role = c("aut", "cre"),
           email = "fabricio_almeidasilva@hotmail.com",
           comment = c(ORCID = "0000-0002-5314-2964")),
    person(given = "Yves",
           family = "Van de Peer",
           role = "aut",
           email = "yves.vandepeer@psb.vib-ugent.be",
           comment = c(ORCID = "0000-0003-4327-3730"))
    )
Description: planttfhunter is used to identify plant transcription factors (TFs) 
    from protein sequence data and classify them into families and subfamilies
    using the classification scheme implemented in PlantTFDB.
    TFs are identified using pre-built hidden Markov model profiles
    for DNA-binding domains. Then, auxiliary and forbidden domains are
    used with DNA-binding domains to classify TFs into families and
    subfamilies (when applicable). Currently, TFs can be classified in
    58 different TF families/subfamilies.
License: GPL-3
URL: https://github.com/almeidasilvaf/planttfhunter
BugReports: https://support.bioconductor.org/t/planttfhunter
biocViews: Software, Transcription, FunctionalPrediction,
        GenomeAnnotation, FunctionalGenomics, HiddenMarkovModel,
        Sequencing, Classification
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.1
SystemRequirements: HMMER <http://hmmer.org/>
Imports: Biostrings, SummarizedExperiment, utils, methods
Suggests: BiocStyle, covr, sessioninfo, knitr, rmarkdown, testthat (>=
        3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
Depends: R (>= 4.2.0)
LazyData: false
git_url: https://git.bioconductor.org/packages/planttfhunter
git_branch: RELEASE_3_23
git_last_commit: 677b1c7
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:08:02 UTC; biocbuild
Author: Fabrício Almeida-Silva [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5314-2964>),
  Yves Van de Peer [aut] (ORCID: <https://orcid.org/0000-0003-4327-3730>)
Maintainer: Fabrício Almeida-Silva <fabricio_almeidasilva@hotmail.com>
Built: R 4.6.0; ; 2026-04-29 04:54:44 UTC; unix
